@@ -1,6 +1,10 @@
+import os
+import sys 
+
 from sqlalchemy import create_engine
 
 from hydenv.models import Base
+from hydenv.util import env
 
 
 class HydenvDatabase:
@@ -16,16 +20,23 @@ class HydenvDatabase:
     def __init__(self, connection="postgresql://postgres:postgres@localhost:5432/postgres"):
         self.connection = connection
 
-    def install(self, db_name='hydenv', role='hydenv', password='changeme', skip_init=False):
+    def install(self, db_name='hydenv', role='hydenv', password='changeme', skip_init=False, env='export'):
         """
         Install the database\n
         The connection passed needs to have granted privileges to create
-        new database instances. Please note that the Postgis extension 
-        has to be installed.
+        new database instances. Please note that the Postgis library 
+        has to be installed.\n
+        The tool will export the connection info to the current command line 
+        session. This behavior can be overwritten.
+        This behavior 
         :param db_name: database name
         :param role: The user for the new database instance
         :param password: The users password, HAS TO BE SET
         :param skip_init: Skip init step to run with other user
+        :param env: Either 'suppress', 'export' or 'file'\n
+            - suppress will do nothing
+            - export will expose connection params as environement variables
+            - file will write them to an .env file.
         :raises AttributeError: if the password was not given
         """
         # create the engine and create the user
@@ -58,18 +69,21 @@ class HydenvDatabase:
         with engine.connect() as con:
             con.execute('CREATE EXTENSION postgis;')
             res = con.execute('Select PostGis_Full_Version();').scalar()
-        
-        if not skip_init:
-            print(res)
             
-            # rebuild the connection
-            host = self.connection.split('@')[1].split('/')[0]
-            self.connection = 'postgresql://{usr}:{pw}@{host}/{db}'.format(
-                usr=role, pw=password, host=host, db=db_name
-            )
+        # rebuild the connection
+        host_port = self.connection.split('@')[1].split('/')[0]
+        host, port = host_port.split(':')
+        self.connection = 'postgresql://{usr}:{pw}@{host}:{port}/{db}'.format(
+            usr=role, pw=password, host=host,port=port, db=db_name
+        )
+        # expose conn if 
+        self.__expose_con(usr=role, pw=password, host=host, port=port, dbname=db_name)
+        
+        if skip_init:
+            print(res)
             self.init()
         else:
-            print(res)
+            return res
 
     def init(self, clean=False):
         """
@@ -89,6 +103,16 @@ class HydenvDatabase:
         Base.metadata.create_all(bind=engine)
         print('Done')
 
+    def __expose_con(self, action, **kwargs):
+        if action.lower() == 'suppress':
+            return
+        elif action.lower() == 'export':
+            env.expose(**kwargs)
+        elif action.lower() == 'file':
+            env.store_file(**kwargs)
+        else:
+            raise AttributeError("env has to be one of 'suppress', 'export' or 'file'")
+
 
 if __name__=='__main__':
     import fire
